@@ -1,5 +1,5 @@
 /* MI Option Parser.
-   Copyright (C) 2000-2016 Free Software Foundation, Inc.
+   Copyright (C) 2000-2019 Free Software Foundation, Inc.
    Contributed by Cygnus Solutions (a Red Hat company).
 
    This file is part of GDB.
@@ -17,8 +17,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef MI_GETOPT_H
-#define MI_GETOPT_H
+#ifndef MI_MI_GETOPT_H
+#define MI_MI_GETOPT_H
 
 /* The option list.  Terminated by NAME==NULL.  ARG_P that the option
    requires an argument.  INDEX is returned to identify the option.  */
@@ -74,5 +74,5 @@ extern int mi_getopt_allow_unknown (const char *prefix, int argc,
    and the appropriate error message is displayed by mi_getopt.  */
 
 extern int mi_valid_noargs (const char *prefix, int argc, char **argv);
-				
-#endif
+
+#endif /* MI_MI_GETOPT_H */
